@@ -6,7 +6,7 @@ skip_unless_socket_available <- function() {
     tryCatch({
     sock <- base::socketConnection(
       host = "localhost", 1984,
-      open = "w+b", server = FALSE, blocking = TRUE, encoding = "utf-8", timeout = 1)
+      open = "w+b", server = FALSE, blocking = FALSE, encoding = "utf-8")
     close(sock)
     TRUE
   }, error = function(e) {
